Coverage report

File | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/otg_mcp/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/__main__.py | 9 | 9 | 20 | 2 | 0 | 0%
src/otg_mcp/client.py | 703 | 441 | 0 | 178 | 11 | 34%
src/otg_mcp/client_capture.py | 90 | 82 | 0 | 10 | 0 | 8%
src/otg_mcp/config.py | 135 | 84 | 0 | 30 | 4 | 35%
src/otg_mcp/models/__init__.py | 2 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/models/models.py | 48 | 1 | 0 | 0 | 0 | 98%
src/otg_mcp/schema_registry.py | 220 | 3 | 0 | 66 | 0 | 99%
src/otg_mcp/server.py | 111 | 81 | 2 | 8 | 0 | 25%
Total | 1318 | 701 | 22 | 294 | 15 | 45%

No items found using the specified filter.